@@ -55,14 +55,6 @@
 #include <QMimeData>
 
 K_PLUGIN_FACTORY(FSViewPartFactory, registerPlugin<FSViewPart>();)
-K_EXPORT_PLUGIN(FSViewPartFactory(KAboutData(
-                                      "fsview",
-                                      0,
-                                      ki18n("FSView"),
-                                      "0.1.1",
-                                      ki18n("Filesystem Utilization Viewer"),
-                                      KAboutData::License_GPL,
-                                      ki18n("(c) 2003-2005, Josef Weidendorfer"))))
 
 // FSJob, for progress
 
@@ -121,7 +113,7 @@ FSViewPart::FSViewPart(QWidget *parentWidget,
     setWidget(_view);
 
     _ext = new FSViewBrowserExtension(this);
-    _job = 0;
+    _job = nullptr;
 
     _areaMenu = new KActionMenu(i18n("Stop at Area"),
                                 actionCollection());
@@ -267,7 +259,7 @@ void FSViewPart::completedSlot(int dirs)
     if (_job) {
         _job->progressSlot(100, dirs, QString());
         delete _job;
-        _job = 0;
+        _job = nullptr;
     }
 
     KConfigGroup cconfig(_view->config(), "MetricCache");
@@ -285,13 +277,13 @@ void FSViewPart::slotShowVisMenu()
 void FSViewPart::slotShowAreaMenu()
 {
     _areaMenu->menu()->clear();
-    _view->addAreaStopItems(_areaMenu->menu(), 1001, 0);
+    _view->addAreaStopItems(_areaMenu->menu(), 1001, nullptr);
 }
 
 void FSViewPart::slotShowDepthMenu()
 {
     _depthMenu->menu()->clear();
-    _view->addDepthStopItems(_depthMenu->menu(), 1501, 0);
+    _view->addDepthStopItems(_depthMenu->menu(), 1501, nullptr);
 }
 
 void FSViewPart::slotShowColorMenu()
@@ -478,7 +470,7 @@ void FSViewBrowserExtension::del()
                                          KIO::JobUiDelegate::Delete, KIO::JobUiDelegate::DefaultConfirmation)) {
         KIO::Job *job = KIO::del(urls);
         KJobWidgets::setWindow(job, _view);
-        job->ui()->setAutoErrorHandlingEnabled(true);
+        job->uiDelegate()->setAutoErrorHandlingEnabled(true);
         connect(job, SIGNAL(result(KJob*)),
                 this, SLOT(refresh()));
     }
@@ -498,7 +490,7 @@ void FSViewBrowserExtension::trash(Qt::MouseButtons, Qt::KeyboardModifiers modif
             KIO::Job *job = KIO::trash(urls);
             KIO::FileUndoManager::self()->recordJob(KIO::FileUndoManager::Trash, urls, QUrl("trash:/"), job);
             KJobWidgets::setWindow(job, _view);
-            job->ui()->setAutoErrorHandlingEnabled(true);
+            job->uiDelegate()->setAutoErrorHandlingEnabled(true);
             connect(job, SIGNAL(result(KJob*)),
                     this, SLOT(refresh()));
         }
