@@ -21,9 +21,7 @@
 
 
 #include <kconfig.h>
-#include <kglobal.h>
 #include <khtml_part.h>
-#include <kcomponentdata.h>
 #include <KLocalizedString>
 #include <kmessagebox.h>
 #include <QMenu>
@@ -49,7 +47,7 @@ K_PLUGIN_FACTORY(SettingsPluginFactory, registerPlugin<SettingsPlugin>();)
 
 SettingsPlugin::SettingsPlugin(QObject *parent,
                                const QVariantList &)
-    : KParts::Plugin(parent), mConfig(0)
+    : KParts::Plugin(parent), mConfig(nullptr)
 {
     setComponentData(KAboutData(QStringLiteral("khtmlsettingsplugin"), i18n("HTML Settings"), QStringLiteral("1.0")));
     KActionMenu *menu = new KActionMenu(QIcon::fromTheme(QStringLiteral("configure")), i18n("HTML Settings"), actionCollection());
