@@ -30,15 +30,15 @@ class KonqViewManager;
 class KonqMainWindow;
 
 /**
- * This is the konqueror sesions administration dialog, which allows the user
+ * This is the konqueror sessions administration dialog, which allows the user
  * to add, modify, rename and delete konqueror sessions.
  */
 class KonqSessionDlg : public KDialog
 {
     Q_OBJECT
 public:
-    explicit KonqSessionDlg(KonqViewManager *manager, QWidget *parent = Q_NULLPTR);
-    ~KonqSessionDlg();
+    explicit KonqSessionDlg(KonqViewManager *manager, QWidget *parent = nullptr);
+    ~KonqSessionDlg() override;
 
 protected Q_SLOTS:
     void slotOpen();
@@ -60,7 +60,7 @@ class KonqNewSessionDlg : public KDialog
 public:
     enum Mode { NewFile, ReplaceFile };
     explicit KonqNewSessionDlg(QWidget *parent, KonqMainWindow *mainWindow, QString sessionName = QString(), Mode mode = NewFile);
-    ~KonqNewSessionDlg();
+    ~KonqNewSessionDlg() override;
 
 protected Q_SLOTS:
     void slotAddSession();
