@@ -28,6 +28,8 @@
 #include "settings/webenginesettings.h"
 #include "webenginepartdownloadmanager.h"
 #include "webenginewallet.h"
+#include <webenginepart_debug.h>
+
 #include <QWebEngineCertificateError>
 #include <QWebEngineSettings>
 #include <QWebEngineProfile>
@@ -46,10 +48,7 @@
 #include <KIO/Scheduler>
 #include <KParts/HtmlExtension>
 #include <KUserTimestamp>
-#include <kio_version.h>
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 30, 0)
 #include <KPasswdServerClient>
-#endif
 
 #include <QStandardPaths>
 #include <QDesktopWidget>
@@ -75,7 +74,7 @@ WebEnginePage::WebEnginePage(WebEnginePart *part, QWidget *parent)
          m_ignoreError(false),
          m_part(part),
          m_passwdServerClient(new KPasswdServerClient),
-         m_wallet(Q_NULLPTR)
+         m_wallet(nullptr)
 {
     if (view())
         WebEngineSettings::self()->computeFontSizes(view()->logicalDpiY());
@@ -155,7 +154,7 @@ void WebEnginePage::download(const QUrl& url, bool newWindow)
 
 QWebEnginePage *WebEnginePage::createWindow(WebWindowType type)
 {
-    //qDebug() << "window type:" << type;
+    //qCDebug(WEBENGINEPART_LOG) << "window type:" << type;
     // Crete an instance of NewWindowPage class to capture all the
     // information we need to create a new window. See documentation of
     // the class for more information...
@@ -189,7 +188,7 @@ bool WebEnginePage::acceptNavigationRequest(const QUrl& url, NavigationType type
     if (m_urlLoadedByPart != url) {
         m_urlLoadedByPart = QUrl();
     }
-//     qDebug() << url << "type=" << type;
+//     qCDebug(WEBENGINEPART_LOG) << url << "type=" << type;
     QUrl reqUrl(url);
 
     // Handle "mailto:" url here...
@@ -201,7 +200,7 @@ bool WebEnginePage::acceptNavigationRequest(const QUrl& url, NavigationType type
     /*
       NOTE: We use a dynamic QObject property called "NavigationTypeUrlEntered"
       to distinguish between requests generated by user entering a url vs those
-      that were generated programatically through javascript (AJAX requests).
+      that were generated programmatically through javascript (AJAX requests).
     */
     if (isMainFrame && isTypedUrl)
       setProperty("NavigationTypeUrlEntered", QVariant());
@@ -236,7 +235,7 @@ bool WebEnginePage::acceptNavigationRequest(const QUrl& url, NavigationType type
             // If history navigation is locked, ignore all such requests...
             if (property("HistoryNavigationLocked").toBool()) {
                 setProperty("HistoryNavigationLocked", QVariant());
-                qDebug() << "Rejected history navigation because 'HistoryNavigationLocked' property is set!";
+                qCDebug(WEBENGINEPART_LOG) << "Rejected history navigation because 'HistoryNavigationLocked' property is set!";
                 return false;
             }
             //kDebug() << "Navigating to item (" << history()->currentItemIndex()
@@ -248,7 +247,7 @@ bool WebEnginePage::acceptNavigationRequest(const QUrl& url, NavigationType type
             inPageRequest = false;
             break;
         case QWebEnginePage::NavigationTypeOther: // triggered by javascript
-            qDebug() << "Triggered by javascript";
+            qCDebug(WEBENGINEPART_LOG) << "Triggered by javascript";
             inPageRequest = !isTypedUrl;
             break;
         default:
@@ -465,7 +464,7 @@ void WebEnginePage::slotFeaturePermissionRequested(const QUrl& url, QWebEnginePa
         setFeaturePermission(url, feature, QWebEnginePage::PermissionGrantedByUser);
         break;
     case QWebEnginePage::Geolocation:
-        if (KMessageBox::warningContinueCancel(0, i18n("This site is attempting to "
+        if (KMessageBox::warningContinueCancel(nullptr, i18n("This site is attempting to "
                                                        "access information about your "
                                                        "physical location.\n"
                                                        "Do you want to allow it access?"),
@@ -503,14 +502,14 @@ void WebEnginePage::slotGeometryChangeRequested(const QRect & rect)
     // parts of following code are based on kjs_window.cpp
     // Security check: within desktop limits and bigger than 100x100 (per spec)
     if (width < 100 || height < 100) {
-        qWarning() << "Window resize refused, window would be too small (" << width << "," << height << ")";
+        qCWarning(WEBENGINEPART_LOG) << "Window resize refused, window would be too small (" << width << "," << height << ")";
         return;
     }
 
     QRect sg = QApplication::desktop()->screenGeometry(view());
 
     if (width > sg.width() || height > sg.height()) {
-        qWarning() << "Window resize refused, window would be too big (" << width << "," << height << ")";
+        qCWarning(WEBENGINEPART_LOG) << "Window resize refused, window would be too big (" << width << "," << height << ")";
         return;
     }
 
@@ -556,10 +555,10 @@ bool WebEnginePage::checkLinkSecurity(const QNetworkRequest &req, NavigationType
         }
 
         if (buttonText.isEmpty()) {
-            KMessageBox::error( 0, message, title);
+            KMessageBox::error( nullptr, message, title);
         } else {
             // Dangerous flag makes the Cancel button the default
-            response = KMessageBox::warningContinueCancel(0, message, title,
+            response = KMessageBox::warningContinueCancel(nullptr, message, title,
                                                           KGuiItem(buttonText),
                                                           KStandardGuiItem::cancel(),
                                                           QString(), // no don't ask again info
@@ -578,7 +577,7 @@ bool WebEnginePage::checkFormData(const QUrl &url) const
 
     if (m_sslInfo.isValid() &&
         !scheme.compare(QL1S("https")) && !scheme.compare(QL1S("mailto")) &&
-        (KMessageBox::warningContinueCancel(0,
+        (KMessageBox::warningContinueCancel(nullptr,
                                            i18n("Warning: This is a secure form "
                                                 "but it is attempting to send "
                                                 "your data back unencrypted.\n"
@@ -594,7 +593,7 @@ bool WebEnginePage::checkFormData(const QUrl &url) const
 
 
     if (scheme.compare(QL1S("mailto")) == 0 &&
-        (KMessageBox::warningContinueCancel(0, i18n("This site is attempting to "
+        (KMessageBox::warningContinueCancel(nullptr, i18n("This site is attempting to "
                                                     "submit form data via email.\n"
                                                     "Do you want to continue?"),
                                             i18n("Network Transmission"),
@@ -646,7 +645,7 @@ bool WebEnginePage::handleMailToUrl (const QUrl &url, NavigationType type) const
 
         switch (type) {
             case QWebEnginePage::NavigationTypeLinkClicked:
-                if (!files.isEmpty() && KMessageBox::warningContinueCancelList(0,
+                if (!files.isEmpty() && KMessageBox::warningContinueCancelList(nullptr,
                                                                                i18n("<qt>Do you want to allow this site to attach "
                                                                                     "the following files to the email message?</qt>"),
                                                                                files, i18n("Email Attachment Confirmation"),
@@ -665,7 +664,7 @@ bool WebEnginePage::handleMailToUrl (const QUrl &url, NavigationType type) const
             case QWebEnginePage::NavigationTypeFormSubmitted:
             //case QWebEnginePage::NavigationTypeFormResubmitted:
                 if (!files.isEmpty()) {
-                    KMessageBox::information(0, i18n("This site attempted to attach a file from your "
+                    KMessageBox::information(nullptr, i18n("This site attempted to attach a file from your "
                                                      "computer in the form submission. The attachment "
                                                      "was removed for your protection."),
                                              i18n("Attachment Removed"), QStringLiteral("InfoTriedAttach"));
@@ -705,11 +704,7 @@ void WebEnginePage::slotAuthenticationRequired(const QUrl &requestUrl, QAuthenti
     info.verifyPath = info.realmValue.isEmpty();
 
     const QString errorMsg = QString();
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 30, 0)
     const int ret = m_passwdServerClient->queryAuthInfo(&info, errorMsg, view()->window()->winId(), KUserTimestamp::userTimestamp());
-#else
-    const int ret = 1; // no KPasswdServerClient until 5.30
-#endif
     if (ret == KJob::NoError) {
         auth->setUser(info.username);
         auth->setPassword(info.password);
@@ -768,7 +763,7 @@ static KParts::BrowserArguments browserArgs(WebEnginePage::WebWindowType type)
 
 bool NewWindowPage::acceptNavigationRequest(const QUrl &url, NavigationType type, bool isMainFrame)
 {
-    //qDebug() << "url:" << url << ", type:" << type << ", isMainFrame:" << isMainFrame << "m_createNewWindow=" << m_createNewWindow;
+    //qCDebug(WEBENGINEPART_LOG) << "url:" << url << ", type:" << type << ", isMainFrame:" << isMainFrame << "m_createNewWindow=" << m_createNewWindow;
     if (m_createNewWindow) {
         const QUrl reqUrl (url);
 
@@ -817,9 +812,9 @@ bool NewWindowPage::acceptNavigationRequest(const QUrl &url, NavigationType type
         // Window args...
         KParts::WindowArgs wargs (m_windowArgs);
 
-        KParts::ReadOnlyPart* newWindowPart =0;
-        part()->browserExtension()->createNewWindow(QUrl(), uargs, bargs, wargs, &newWindowPart);
-        qDebug() << "Created new window" << newWindowPart;
+        KParts::ReadOnlyPart* newWindowPart =nullptr;
+        emit part()->browserExtension()->createNewWindow(QUrl(), uargs, bargs, wargs, &newWindowPart);
+        qCDebug(WEBENGINEPART_LOG) << "Created new window" << newWindowPart;
 
         if (!newWindowPart) {
             return false;
@@ -831,11 +826,11 @@ bool NewWindowPage::acceptNavigationRequest(const QUrl &url, NavigationType type
 
         // Get the webview...
         WebEnginePart* webenginePart = qobject_cast<WebEnginePart*>(newWindowPart);
-        WebEngineView* webView = webenginePart ? qobject_cast<WebEngineView*>(webenginePart->view()) : 0;
+        WebEngineView* webView = webenginePart ? qobject_cast<WebEngineView*>(webenginePart->view()) : nullptr;
 
         // If the newly created window is NOT a webenginepart...
         if (!webView) {
-            qDebug() << "Opening URL on" << newWindowPart;
+            qCDebug(WEBENGINEPART_LOG) << "Opening URL on" << newWindowPart;
             newWindowPart->openUrl(reqUrl);
             this->deleteLater();
             return false;
@@ -896,7 +891,6 @@ void NewWindowPage::slotToolBarVisibilityChangeRequested(bool visible)
 void NewWindowPage::slotLoadFinished(bool ok)
 {
     Q_UNUSED(ok)
-    qDebug() << ok;
     if (!m_createNewWindow)
         return;
 
@@ -914,14 +908,14 @@ void NewWindowPage::slotLoadFinished(bool ok)
     // Window args...
     KParts::WindowArgs wargs (m_windowArgs);
 
-    KParts::ReadOnlyPart* newWindowPart =0;
-    part()->browserExtension()->createNewWindow(QUrl(), uargs, bargs, wargs, &newWindowPart);
+    KParts::ReadOnlyPart* newWindowPart =nullptr;
+    emit part()->browserExtension()->createNewWindow(QUrl(), uargs, bargs, wargs, &newWindowPart);
 
-    qDebug() << "Created new window or tab" << newWindowPart;
+    qCDebug(WEBENGINEPART_LOG) << "Created new window or tab" << newWindowPart;
 
     // Get the webview...
-    WebEnginePart* webenginePart = newWindowPart ? qobject_cast<WebEnginePart*>(newWindowPart) : 0;
-    WebEngineView* webView = webenginePart ? qobject_cast<WebEngineView*>(webenginePart->view()) : 0;
+    WebEnginePart* webenginePart = newWindowPart ? qobject_cast<WebEnginePart*>(newWindowPart) : nullptr;
+    WebEngineView* webView = webenginePart ? qobject_cast<WebEngineView*>(webenginePart->view()) : nullptr;
 
     if (webView) {
         // if a new window is created, set a new window meta-data flag.
